@@ -4,6 +4,8 @@ from datetime import datetime
 
 import darkdetect
 
+from .__init__ import SEP
+
 
 def darkdetect_callback(arg):
     global colors_map
@@ -14,6 +16,42 @@ def darkdetect_callback(arg):
         colors_map = dark_colors
 
 
+def hide_first_dirs(path: str, from_depth: int) -> str:
+    if path.count(SEP) <= from_depth:
+        return path
+
+    first_slice_end = path.index(SEP) + 1
+
+    second_slice_start = len(path) - 1
+    for _ in range(from_depth):
+        second_slice_start = path.rindex(SEP, 0, second_slice_start)
+
+    removed = path[first_slice_end:second_slice_start]
+    ast = '*' * (1 + int(removed.count(SEP) > 0))
+
+    res = path[:first_slice_end] + ast + path[second_slice_start:]
+    return res
+
+
+def reduce_big_path_names(path: str, max_size: int) -> str:
+    names = path.split(SEP)
+
+    for idx in range(len(names)):
+        size = len(names[idx])
+        if size > max_size:
+            middle = int(max_size // 2)
+            end_slice = middle - 1
+            start_slice = size - middle + 1
+
+            names[idx] = (
+                names[idx][:end_slice]
+                + '...'
+                + names[idx][start_slice:]
+            )
+
+    return SEP.join(names)
+
+
 def resolve_duration(seconds: float) -> str:
     # return like: 2h, 1h3m, 4m, 2m5s, 58.4s
     minutes = int(seconds / 60)
@@ -33,6 +71,21 @@ def resolve_duration(seconds: float) -> str:
     return res
 
 
+def resolve_clocks(duration: float, width: int) -> str:
+    res = resolve_duration(duration)
+    if res:
+        res = symbols_map['Duration'] + ' ' + res
+
+    if width - len(res) - 11 >= 0:
+        time_str = datetime.now().strftime('%H:%M:%S')
+        if res:
+            res += ' ' + symbols_map['Clock'] + ' ' + time_str
+        else:
+            res += symbols_map['Clock'] + ' ' + time_str
+
+    return res
+
+
 # maybe will be relevant:    
 def style(
     cwd: str,
@@ -56,21 +109,26 @@ def style(
     else:
         cwd = ' ' + cwd
 
-    result += colors_map['Cwd'] + cwd + colors_map['reset'] + ' '
+    cwd = hide_first_dirs(cwd, 5)
+    cwd = reduce_big_path_names(cwd, 25)
+
+    result += colors_map['Cwd'] + cwd + colors_map['Reset'] + ' '
 
     if not equal:
+        link = hide_first_dirs(link, 5)
+        link = reduce_big_path_names(link, 25)
         result += (
             colors_map['Link']
             + ' '
             + colors_map['Cwd']
             + link
-            + colors_map['reset']
+            + colors_map['Reset']
             + ' '
         )
 
     if git:
         result += (
-            colors_map['Git'] + symbols_map['Git'] + colors_map['reset'] + ' '
+            colors_map['Git'] + symbols_map['Git'] + colors_map['Reset'] + ' '
         )
 
     for item in brackets:
@@ -79,47 +137,44 @@ def style(
         result += '[' + colors_map[symbol] + symbols_map[symbol]
         if symbol != 'Status':
             result += ' '
-        result += text + colors_map['reset'] + '] '
+        result += text + colors_map['Reset'] + '] '
 
     for item in after:
         result += (
-            colors_map[item] + symbols_map[item] + colors_map['reset'] + ' '
+            colors_map[item] + symbols_map[item] + colors_map['Reset'] + ' '
         )
 
+    # remove last empty space, new line might be in there
+    result = result.strip()
+
     # get the lenght of written so far
-    aux = result
+    raw = result
     for item in colors_map:
-        aux = aux.replace(colors_map[item], '', -1)
-    width -= len(aux) + 11  # will be the size of datetime.now
-    # clock: 2, space, hh:mm:ss -> 11
+        raw = raw.replace(colors_map[item], '', -1)
 
-    for char in chars_with_double_lenght:
-        if char in result:
-            width -= 1
+    width -= len(raw) + int('🌙' in raw) + 1  # new line at the end
 
-    duration = resolve_duration(duration)
-    if duration:
-        width -= len(duration) + 3  # symbol, space before, space after
-        result += ' ' * width + symbols_map['Duration'] + f' {duration} '
-    else:
-        result += ' ' * width
+    clocks_str = resolve_clocks(duration, width)
+    if clocks_str:
+        result += ' '
+        width -= 1
 
-    time_str = datetime.now().strftime('%H:%M:%S')
-    result += symbols_map['Clock'] + ' ' + time_str
+    width -= len(clocks_str) - int('🕓' not in clocks_str)
+    result += ' ' * width + clocks_str
+
+    if width > 0:
+        result += '\n'
 
     if no_error:
-        result += colors_map['no_error']
+        result += colors_map['No_error']
     else:
-        result += colors_map['error']
+        result += colors_map['Error']
 
-    result += '❯ ' + colors_map['reset']
+    result += '❯ ' + colors_map['Reset']
 
     return result
 
 
-chars_with_double_lenght = '🌙🕓'
-
-# this antipattern makes easier to know the 'length' of chars
 symbols_map = {
     'Git': '',
     'Branch': '',
@@ -131,7 +186,8 @@ symbols_map = {
     'Pwsh': '',  # maybe  
     'Status': '',
     'Clock': '🕓',
-    'Duration': ''
+    'Duration': '',
+    'Error': '✘'
 }
 
 light_colors = {
@@ -146,9 +202,9 @@ light_colors = {
     'Cpp': "\x1b[34m",
     'Pwsh': "\x1b[34m",
     'Status': "\x1b[31m",
-    'reset': "\x1b[0m",
-    'no_error': "\x1b[32m",
-    'error': "\x1b[31m"
+    'Reset': "\x1b[0m",
+    'No_error': "\x1b[32m",
+    'Error': "\x1b[31m"
 }
 
 dark_colors = {
@@ -163,13 +219,13 @@ dark_colors = {
     'Cpp': "\x1b[94m",
     'Pwsh': "\x1b[94m",
     'Status': "\x1b[91m",
-    'reset': "\x1b[0m",
-    'no_error': "\x1b[92m",
-    'error': "\x1b[91m"
+    'Reset': "\x1b[0m",
+    'No_error': "\x1b[92m",
+    'Error': "\x1b[91m"
 }
 
 colors_map = dark_colors if darkdetect.isDark() else light_colors
 
-t = threading.Thread(target=darkdetect.listener, args=(darkdetect_callback,))
-t.daemon = True
-t.start()
+threading.Thread(
+    target=darkdetect.listener, args=(darkdetect_callback,), daemon=True
+).start()
